1.0.0 API documentation: matrix_double2x3_precision.hpp File Reference

| 1.0.0 API documentation

Typedefs
matrix_double2x3_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 2, 3, double, highp > | highp_dmat2x3
| 2 columns of 3 components matrix of double-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...
typedef mat< 2, 3, double, lowp > | lowp_dmat2x3
| 2 columns of 3 components matrix of double-precision floating-point numbers using low precision arithmetic in term of ULPs. More...
typedef mat< 2, 3, double, mediump > | mediump_dmat2x3
| 2 columns of 3 components matrix of double-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...

## Detailed Description

Core features

Definition in file matrix_double2x3_precision.hpp.